Talker class

Talker - advanced exception handling and logging for dart/flutter applications

Available extensions

Constructors

Talker({TalkerLogger? logger, TalkerObserver? observer, TalkerSettings? settings, TalkerFilter? filter, TalkerErrorHandler? errorHandler, TalkerHistory? history})
Talker base constructor

Properties

filter TalkerFilter
TalkerFilter filter - filter for selecting specific logs and errors by their keys TalkerData.key and by string query TalkerFilter.searchQuery You can set it in configure method or change it later
no setter
hashCode int
The hash code for this object.
no setterinherited
history List<TalkerData>
The history stores all information about all events like occurred errors TalkerErrors, exceptions TalkerExceptions and logs TalkerLogs that have been sent
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings TalkerSettings
Fields can be setup in configure() method
getter/setter pair
stream Stream<TalkerData>
Common stream to sent all processed events TalkerData occurred errors TalkerErrors, exceptions TalkerExceptions and logs TalkerLogs that have been sent You can connect a listener to it and catch the received errors
no setter

Methods

cleanHistory() → void
Clear log history
configure({TalkerLogger? logger, TalkerSettings? settings, TalkerObserver? observer, TalkerFilter? filter, TalkerErrorHandler? errorHandler, TalkerHistory? history}) → void
Setup configuration of Talker
critical(dynamic msg, [Object? exception, StackTrace? stackTrace]) → void
Log a new critical message dynamic message - message describes what happened Object? exception - exception if it happened StackTrace? stackTrace - stackTrace if exception happened
debug(dynamic msg, [Object? exception, StackTrace? stackTrace]) → void
Log a new debug message dynamic message - message describes what happened Object? exception - exception if it happened StackTrace? stackTrace - stackTrace if exception happened
disable() → void
Method stops all Talker works
enable() → void
Method run all Talker works
error(dynamic msg, [Object? exception, StackTrace? stackTrace]) → void
Log a new error message dynamic message - message describes what happened Object? exception - exception if it happened StackTrace? stackTrace - stackTrace if exception happened
handle(Object exception, [StackTrace? stackTrace, dynamic msg]) → void
Handle common exceptions in your code Object exception - exception StackTrace? stackTrace - stackTrace String? msg - message describes what happened
info(dynamic msg, [Object? exception, StackTrace? stackTrace]) → void
Log a new info message dynamic message - message describes what happened Object? exception - exception if it happened StackTrace? stackTrace - stackTrace if exception happened
log(dynamic message, {LogLevel logLevel = LogLevel.debug, Object? exception, StackTrace? stackTrace, AnsiPen? pen}) → void
Log a new message with maximal customization String message - message describes what happened LogLevel logLevel - to control logging output Object? exception - exception if it happened StackTrace? stackTrace - stackTrace if exception happened Map<String, dynamic>? additional - additional log data for your own further logic processing AnsiPen? pen - sets your own log color for console
logCustom(TalkerLog log) → void
Log a new message created in the full TalkerLog model or they subclass (you can create it by extends of TalkerLog)
logTyped(TalkerLog log) → void
Log a new message created in the full TalkerLog model or they subclass (you can create it by extends of TalkerLog)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
verbose(dynamic msg, [Object? exception, StackTrace? stackTrace]) → void
Log a new verbose message dynamic message - message describes what happened Object? exception - exception if it happened StackTrace? stackTrace - stackTrace if exception happened
warning(dynamic msg, [Object? exception, StackTrace? stackTrace]) → void
Log a new warning message dynamic message - message describes what happened Object? exception - exception if it happened StackTrace? stackTrace - stackTrace if exception happened

Operators

operator ==(Object other) bool
The equality operator.
inherited