TalkerFilter class

Constructors

TalkerFilter({List<String> enabledKeys = const [], List<String> disabledKeys = const [], String? searchQuery})

Properties

disabledKeys List<String>
List of disabled for filter keys This is a new way to filter logs by their keys. Keys are unique identifiers for logs, which can be set when creating a log. All original talker keys here TalkerKey
final
enabledKeys List<String>
List of enabled for filter keys This is a new way to filter logs by their keys. Keys are unique identifiers for logs, which can be set when creating a log. All original talker keys here TalkerKey
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchQuery String?
String query for filtering logs
final

Methods

copyWith({List<String>? enabledKeys, List<String>? disabledKeys, String? searchQuery}) TalkerFilter
filter(TalkerData item) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited