enabledKeys property

List<String> enabledKeys
final

List of enabled for filter keys This is a new way to filter logs by their keys. Keys are unique identifiers for logs, which can be set when creating a log. All original talker keys here TalkerKey

Implementation

final List<String> enabledKeys;