TalkerJsonFormatter class

Formatter for converting data to pretty JSON strings.

Use const TalkerJsonFormatter() for standard JSON formatting, TalkerJsonFormatter(stripQuotes: true) to strip quotes, or TalkerJsonFormatter.custom(fn) for custom formatting.

Constructors

TalkerJsonFormatter({bool stripQuotes = false})
Creates a formatter with optional quote stripping.
const
TalkerJsonFormatter.custom(String _customFormatter(dynamic data)?)
Creates a formatter with a custom formatting function.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stripQuotes bool
Whether to strip double quotes from JSON output.
final

Methods

format(dynamic data) String
Formats the given data to a pretty JSON string.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited