registeredKeys property

List<String> registeredKeys
final

A list of TalkerKeys that can be included in filter by TalkerScreen settings This allows you to register custom keys that can be used for filtering logs in the Talker UI.

Implementation

final List<String> registeredKeys = [];