TalkerSettings class
This class used for setup Talker configuration
Constructors
Properties
-
colors
→ Map<
String, AnsiPen> -
Custom Logger Colors.
final
- enabled ↔ bool
-
Use writing talker records in file
The main rule that is responsible
for the operation of the package
All log and handle error / exception methods are working when
trueand not working whenfalsegetter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- maxHistoryItems → int
-
Max records count in history list
no setter
-
registeredKeys
→ List<
String> -
A list of TalkerKeys that can be included in filter by TalkerScreen settings
This allows you to register custom keys that can be used for filtering logs in the Talker UI.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeFormat → TimeFormat
-
The time format of the logs TimeFormat
no setter
-
titles
→ Map<
String, String> -
Custom Logger Titles.
final
- useConsoleLogs → bool
-
By default talker print all Errors / Exceptions and logs in console.
If
true- printing in consolefalse- not printing.no setter - useHistory → bool
-
By default talker write all Errors / Exceptions and logs in history list
(base dart List field in core)
If
true- writing in history Iffalse- not writingno setter
Methods
-
copyWith(
{bool? enabled, bool? useHistory, bool? useConsoleLogs, int? maxHistoryItems, Map< String, String> ? titles, Map<String, AnsiPen> ? colors}) → TalkerSettings -
getPenByKey(
String key, {AnsiPen? fallbackPen}) → AnsiPen -
getTitleByKey(
String key) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerKeys(
List< String> keys) → void - Registers multiple custom keys for filtering logs in the Talker UI
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited